@@ -22,6 +22,8 @@
 #include <string>
 #include <sstream>
 extern "C" {
+  #include <sys/types.h> // for chmod
+  #include <sys/stat.h> // for chmod
   #include <glib/gi18n.h>
 }
 #include <pan/general/debug.h>
@@ -51,6 +53,7 @@ extern "C" {
 #include "progress-view.h"
 #include "profiles-dialog.h"
 #include "post-ui.h"
+#include "render-bytes.h"
 #include "save-ui.h"
 #include "score-add-ui.h"
 #include "score-view-ui.h"
@@ -1177,11 +1180,21 @@ GUI :: do_post ()
   GMimeMessage * message = g_mime_message_new (false);
 
   // add newsgroup...
-  Quark group (_header_pane->get_group ());
-  if (group.empty())
-    group = _group_pane->get_first_selection ();
-  if (!group.empty())
-    g_mime_message_add_header (message, "Newsgroups", group.c_str());
+  std::string newsgroups;
+  const quarks_v groups (_group_pane->get_full_selection ());
+  foreach_const (quarks_v, groups, it) {
+    newsgroups += *it;
+    newsgroups += ',';
+  }
+  if (!newsgroups.empty())
+    newsgroups.resize (newsgroups.size()-1); // erase trailing comma
+  if (newsgroups.empty()) {
+    const Quark group (_header_pane->get_group());
+    if (!group.empty())
+      newsgroups = group;
+  }
+  if (!newsgroups.empty())
+    g_mime_message_add_header (message, "Newsgroups", newsgroups.c_str());
 
   // content type
   GMimePart * part = g_mime_part_new ();
@@ -1734,13 +1747,23 @@ GUI :: set_queue_size_label (unsigned int running,
   char str[128];
   char tip[128];
 
-  // build the format strings
-  g_snprintf (tip, sizeof(tip), _("%u Tasks Running, %u Tasks Total"), running, size);
+  // build the button label
   if (!size)
     g_snprintf (str, sizeof(str), _("No Tasks"));
   else
     g_snprintf (str, sizeof(str), "%s: %u/%u", _("Tasks"), running, size);
 
+  // build the tooltip
+  gulong queued, unused, stopped;
+  guint64 KiB_remain;
+  double KiBps;
+  int hr, min, sec;
+  _queue.get_stats (queued, unused, stopped,
+                    KiB_remain, KiBps,
+                    hr, min, sec);
+  g_snprintf (tip, sizeof(tip), _("%lu tasks, %s, %.1f KiBps, ETA %d:%02d:%02d"),
+              (running+queued), render_bytes(KiB_remain), KiBps, hr, min, sec);
+
   // update the gui
   gtk_label_set_text (GTK_LABEL(_queue_size_label), str);
   gtk_tooltips_set_tip (GTK_TOOLTIPS(_ttips), _queue_size_button, tip, NULL);
