@@ -15,22 +15,16 @@ const char * fallback_post_ui =
 "      <menuitem action='paste' />\n"
 "      <menuitem action='rot13' />\n"
 "      <separator />\n"
-"      <menu action='charsets-menu'>\n"
-"        <placeholder name='charset-list' />\n"
-"      </menu>\n"
+"      <menuitem action='set-charset' />\n"
 "      <menuitem action='remember-charset' />\n"
 "      <separator />\n"
-"      <menuitem action='manage-profiles' />\n"
-"      <separator />\n"
 "      <menuitem action='run-editor' />\n"
-"      <menu action='editors-menu'>\n"
-"        <placeholder name='editor-list' />\n"
-"      </menu>\n"
-"      <menuitem action='manage-editors' />\n"
+"      <menuitem action='always-run-editor' />\n"
 "      <separator />\n"
 "      <menuitem action='wrap' />\n"
-"      <separator />\n"
 "      <menuitem action='spellcheck' />\n"
+"      <separator />\n"
+"      <menuitem action='manage-profiles' />\n"
 "    </menu>\n"
 "  </menubar>\n"
 "\n"
