@@ -27,6 +27,8 @@ extern "C" {
 using namespace pan;
 
 ProgressView :: ProgressView ():
+  _progress_step_idle_tag (0),
+  _progress_status_idle_tag (0),
   _root (gtk_event_box_new ()),
   _progressbar (gtk_progress_bar_new ()),
   _progress (0)
@@ -51,18 +53,13 @@ ProgressView :: set_progress (Progress * progress)
       _progress = 0;
     }
 
-    int my_of_100 (0);
-    std::string status;
     if (progress)
     {
       _progress = progress;
       _progress->add_listener (this);
-      my_of_100 = _progress->get_progress_of_100 ();
-      status = _progress->get_status ();
     }
-
-    gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR(_progressbar), my_of_100/100.0);
-    gtk_progress_bar_set_text (GTK_PROGRESS_BAR(_progressbar), status.c_str());
+    update_text_soon ();
+    update_percentage_soon ();
   }
 }
 
@@ -72,15 +69,48 @@ ProgressView :: on_progress_error (Progress& p, const StringView& s)
   on_progress_status (p, s);
 }
 
+gboolean
+ProgressView :: on_progress_step_idle (gpointer self_gpointer)
+{
+  ProgressView * self (static_cast<ProgressView*>(self_gpointer));
+  const int of_100 (self->_progress ? self->_progress->get_progress_of_100() : 0);
+  gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR(self->_progressbar), of_100/100.0);
+  self->_progress_step_idle_tag = 0;
+  return false;
+}
+
+void
+ProgressView :: update_percentage_soon ()
+{
+  if (!_progress_step_idle_tag)
+       _progress_step_idle_tag = g_timeout_add (333, on_progress_step_idle, this);
+}
 void
 ProgressView :: on_progress_step (Progress& p, int of_100)
 {
-  if (0<=of_100 && of_100<=100)
-    gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR(_progressbar), of_100/100.0);
+  update_percentage_soon ();
+}
+
+gboolean
+ProgressView :: on_progress_status_idle (gpointer self_gpointer)
+{
+  ProgressView * self (static_cast<ProgressView*>(self_gpointer));
+  std::string status;
+  if (self->_progress)
+    status = self->_progress->get_status();
+  gtk_progress_bar_set_text (GTK_PROGRESS_BAR(self->_progressbar), status.c_str());
+  self->_progress_status_idle_tag = 0;
+  return false;
 }
 
 void
 ProgressView :: on_progress_status (Progress& p, const StringView& s)
 {
-  gtk_progress_bar_set_text (GTK_PROGRESS_BAR(_progressbar), s.str);
+  update_text_soon ();
+}
+void
+ProgressView :: update_text_soon ()
+{
+  if (!_progress_status_idle_tag)
+       _progress_status_idle_tag = g_timeout_add (333, on_progress_status_idle, this);
 }
