@@ -89,7 +89,7 @@ namespace
 
     d->server = server;
 
-    int port(119), max_conn(4), age(31), rank(1);
+    int port(119), max_conn(4), age(31*3), rank(1);
     std::string addr, user, pass;
     if (!server.empty()) {
       d->data.get_server_addr (server, addr, port);
@@ -198,13 +198,14 @@ pan :: server_edit_dialog_new (Data& data, Queue& queue, GtkWindow * window, con
   ServerEditDialog * d (new ServerEditDialog (data, queue));
 
   // create the dialog
-  const char * title (server.empty() ? _("Pan: Add a Server") : _("Pan: Edit a Server's Settings"));
+  char * title = g_strdup_printf ("Pan: %s", server.empty() ? _("Add a Server") : _("Edit a Server's Settings"));
   GtkWidget * dialog = gtk_dialog_new_with_buttons (title,
                                                     GTK_WINDOW(window),
                                                     GTK_DIALOG_DESTROY_WITH_PARENT,
                                                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                                     GTK_STOCK_OK, GTK_RESPONSE_OK,
                                                     NULL);
+  g_free (title);
   gtk_window_set_role (GTK_WINDOW(dialog), "pan-edit-server-dialog");
   d->dialog = dialog;
   g_object_set_data_full (G_OBJECT(dialog), "dialog", d, delete_server_edit_dialog);
@@ -252,14 +253,16 @@ pan :: server_edit_dialog_new (Data& data, Queue& queue, GtkWindow * window, con
     HIG::workarea_add_section_spacer (t, row, 2);
 
     const int DEFAULT_MAX_PER_SERVER (4);
-    a = GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 1.0, DEFAULT_MAX_PER_SERVER, 1.0, 1.0, 1.0));
+    a = GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, DEFAULT_MAX_PER_SERVER, 1.0, 1.0, 1.0));
     d->connection_limit_spin = w = gtk_spin_button_new (GTK_ADJUSTMENT(a), 1.0, 0u);
     HIG::workarea_add_row (t, &row, _("Connection _Limit:"), w, NULL);
 
     struct { int type; const char * str; } items[] = {
       { 14,  N_("After Two Weeks") },
       { 31,  N_("After One Month") },
-      { 62,  N_("After Two Months") },
+      { (31*2),  N_("After Two Months") },
+      { (31*3),  N_("After Three Months") },
+      { (31*6),  N_("After Six Months") },
       { 0,   N_("Never Expire Old Articles") }
     };
     GtkListStore * store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
@@ -415,7 +418,6 @@ namespace
       std::string addr;
       d->data.get_server_addr (selected_server, addr, port);
 
-      // you don't /really/ wan to do this, do you?
       GtkWidget * w = gtk_message_dialog_new (GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(button))),
                                               GtkDialogFlags(GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT),
                                               GTK_MESSAGE_QUESTION,
@@ -491,11 +493,12 @@ pan :: server_list_dialog_new (Data& data, Queue& queue, GtkWindow* parent)
   ServerListDialog * d = new ServerListDialog (data, queue);
 
   // dialog
-  GtkWidget * w = d->dialog = gtk_dialog_new_with_buttons (_("Pan: Servers"),
-                                                           parent,
+  char * title = g_strdup_printf ("Pan: %s", _("Servers"));
+  GtkWidget * w = d->dialog = gtk_dialog_new_with_buttons (title, parent,
                                                            GTK_DIALOG_DESTROY_WITH_PARENT,
                                                            GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
                                                            NULL);
+  g_free (title);
   gtk_window_set_role (GTK_WINDOW(w), "pan-servers-dialog");
   gtk_window_set_policy (GTK_WINDOW(w), TRUE, TRUE, TRUE);
   g_signal_connect (GTK_OBJECT(w), "response", G_CALLBACK(server_list_dialog_response_cb), d);
