@@ -25,10 +25,11 @@ extern "C" {
 }
 #include <pan/general/debug.h>
 #include <pan/general/foreach.h>
-#include <pan/usenet-utils/utf8-utils.h>
+#include <pan/general/utf8-utils.h>
 #include <pan/tasks/queue.h>
 #include <pan/icons/pan-pixbufs.h>
 #include "pad.h"
+#include "render-bytes.h"
 #include "task-pane.h"
 
 enum
@@ -198,36 +199,6 @@ void TaskPane :: on_queue_online_changed (Queue&, bool online)
 #endif
 }
 
-
-/***
-****
-***/
-
-namespace
-{
-  static const unsigned long KIBI (1024ul);
-  static const unsigned long MEBI (1048576ul);
-  static const unsigned long GIBI (1073741824ul);
-
-  char*
-  render_bytes (guint64 bytes)
-  {
-    static char buf[128];
-
-    if (bytes < KIBI)
-      g_snprintf (buf, sizeof(buf), "%d B", (int)bytes);
-    else if (bytes < MEBI)
-      g_snprintf (buf, sizeof(buf), "%.0f KiB", (double)bytes/KIBI);
-    else if (bytes < GIBI)
-      g_snprintf (buf, sizeof(buf), "%.1f MiB", (double)bytes/MEBI);
-    else
-      g_snprintf (buf, sizeof(buf), "%.2f GiB", (double)bytes/GIBI);
-
-    return buf;
-  }
-}
-
-
 void
 TaskPane :: update_status (const task_states_t& tasks)
 {
@@ -239,11 +210,11 @@ TaskPane :: update_status (const task_states_t& tasks)
   {
     Task * task (*it);
     const Queue::TaskState state (tasks.get_state (task));
-    if (state == Queue::RUNNING)
+    if (state == Queue::RUNNING || state == Queue::DECODING)
       ++running_count;
     else if (state == Queue::STOPPED)
       ++stopped_count;
-    else if (state == Queue::QUEUED)
+    else if (state == Queue::QUEUED || state == Queue::QUEUED_FOR_DECODE)
       ++queued_count;
 
     if (state==Queue::RUNNING || state==Queue::QUEUED)
@@ -265,8 +236,8 @@ TaskPane :: update_status (const task_states_t& tasks)
   double KiBps (_queue.get_speed_KiBps ());
   int hours(0), minutes(0), seconds(0);
   if (task_count) {
-    const double KiB ((double)bytes / KIBI);
-    unsigned long tmp ((unsigned long)(KiB / KiBps));
+    const double KiB ((double)bytes / 1024);
+    unsigned long tmp (KiBps>0.01 ? ((unsigned long)(KiB / KiBps)) : 0);
     seconds = tmp % 60ul; tmp /= 60ul;
     minutes = tmp % 60ul; tmp /= 60ul;
     hours   = tmp;
@@ -278,7 +249,7 @@ TaskPane :: update_status (const task_states_t& tasks)
   const tasks_t tasks_selected (get_selected_tasks ());
   const unsigned long selected_count (tasks_selected.size());
   if (selected_count) {
-    unsigned long selected_bytes (0ul);
+    guint64 selected_bytes (0ul);
     foreach_const (tasks_t, tasks_selected, it)
       selected_bytes += (*it)->get_bytes_remaining ();
     g_snprintf (buf, sizeof(buf), _("%lu selected, %s"), selected_count, render_bytes(selected_bytes));
@@ -344,6 +315,8 @@ namespace
     const char * state_str (0);
     switch (state) {
       case Queue::RUNNING:  state_str = _("Running"); break;
+      case Queue::DECODING: state_str = _("Decoding"); break;
+      case Queue::QUEUED_FOR_DECODE: state_str = _("Queued for Decode"); break;
       case Queue::QUEUED:   state_str = _("Queued"); break;
       case Queue::STOPPED:  state_str = _("Stopped"); break;
       case Queue::REMOVING: state_str = _("Removing"); break;
@@ -401,7 +374,7 @@ namespace
     }
 
     char * str (0);
-    if (state == Queue::RUNNING)
+    if (state == Queue::RUNNING || state == Queue::DECODING)
       str = g_markup_printf_escaped ("<b>%s</b>\n<small>%s</small>", description.c_str(), status.c_str());
     else
       str = g_markup_printf_escaped ("%s\n<small>%s</small>", description.c_str(), status.c_str());
